class ResponseTest < MiniTest::Unit::TestCase

  def setup
    @test_msg = ['+', 1, 2, 3]
    @test_sign = '2446e1d1a2947cfac9bbb0290b40d413'
    @test_resp = [@test_sign, ['+', 1, 2, 3]]
    @resp = Fastbeans::Response.new(@test_msg, @test_resp)
    @err_resp = { 'fastbeans-error' => 'Total screw-up',
                  'error-information' => 'No ways to recover.'}
    @eresp = Fastbeans::Response.new(@test_msg, @err_resp)
  end

  def test_error?
    assert @eresp.error?
    assert !@resp.error?
  end

  def test_signature
    assert_nil @eresp.signature
    assert_equal @test_sign, @resp.signature
  end

  def test_signed_with
    assert @resp.signed_with?(@test_sign)
  end

  def test_payload_for_errors
    begin
      @eresp.payload
    rescue Fastbeans::AutogeneratedException => e
      assert_equal 'Fastbeans::TotalScrewUp', e.class.to_s
    end
  end

  def test_payload
    assert_equal @test_msg, @resp.payload
  end

  def test_support_methods
    assert_equal 'hello_word', @resp.underscore('hello-word')
    assert_equal 'hello_word', @resp.underscore('hello  word')
    assert_equal 'HelloWord', @resp.camelize('hello_word')
    assert_equal 'ABC', @resp.camelize('a_b_c')
  end
end
